==> lxqt-session_0.9.0+20150807.orig.tar.xz: lxqt-session-0.9.0+20150807/lxqt-leave/translations/lxqt-leave_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Form</source>
        <translation>Меню выхода</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="29"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Что вы хотите сделать с компьютером?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="45"/>
        <source>Logout</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="55"/>
        <source>Reboot</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="65"/>
        <source>Shutdown</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="75"/>
        <source>Suspend</source>
        <translation>Перевести в ждущий режим</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="85"/>
        <source>Hibernate</source>
        <translation>Перевести в спящий режим</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="114"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Logout.</source>
        <translation>Выйти.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Lockscreen.</source>
        <translation>Блокировать экран.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Suspend.</source>
        <translation>Перевести в ждущий режим.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Hibernate.</source>
        <translation>Перевести в спящий режим.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>Shutdown.</source>
        <translation>Выключить.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Reboot.</source>
        <translation>Перезагрузить.</translation>
    </message>
</context>
</TS>

==> lxqt-session_0.14.1.orig.tar.xz: lxqt-session-0.14.1/lxqt-leave/translations/lxqt-leave_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Что вы хотите сделать с компьютером?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="51"/>
        <source>Logout</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="69"/>
        <source>Reboot</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="56"/>
        <source>Shutdown</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="61"/>
        <source>Suspend</source>
        <translation>Перевести в ждущий режим</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="66"/>
        <source>Lock screen</source>
        <translation>Заблокировать экран</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="74"/>
        <source>Hibernate</source>
        <translation>Перевести в спящий режим</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Logout.</source>
        <translation>Выйти.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Lockscreen.</source>
        <translation>Заблокировать экран.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Suspend.</source>
        <translation>Перевести в ждущий режим.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Hibernate.</source>
        <translation>Перевести в спящий режим.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Shutdown.</source>
        <translation>Выключить.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Reboot.</source>
        <translation>Перезагрузить.</translation>
    </message>
</context>
</TS>
